View Source mix workspace.status (Workspace v0.1.1)
Similar to git status but on a workspace level.
$ mix workspace.status
Command line options
--base(string) - The base git reference to compare the head to. Applied only when--affectedor--modifiedare set.--config-path(string) - The path to the workspace config to be used, relative to the workspace path [default:.workspace.exs]--head(string) - A reference to the git head. Applied only if--baseis set for getting the changed files [default:HEAD]--workspace-path(string) - If set it specifies the root workspace path, defaults to current directory